@@ -1,3 +1,4 @@
+mod clean_unused;
 mod ser;
 
 use std::{
@@ -11,6 +12,8 @@ pub(crate) use ser::Document;
 use serde::{ser::SerializeMap, Serialize, Serializer};
 use serde_json::Value;
 
+use crate::types::Type;
+
 #[allow(clippy::trivially_copy_pass_by_ref)]
 #[inline]
 const fn is_false(value: &bool) -> bool {
@@ -50,7 +53,7 @@ pub struct MetaSchema {
     #[serde(skip_serializing_if = "Option::is_none")]
     pub format: Option<&'static str>,
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub title: Option<&'static str>,
+    pub title: Option<String>,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub description: Option<&'static str>,
     #[serde(skip_serializing_if = "Option::is_none")]
@@ -666,6 +669,19 @@ impl Registry {
         }
     }
 
+    pub fn create_fake_schema<T: Type>(&mut self) -> MetaSchema {
+        match T::schema_ref() {
+            MetaSchemaRef::Inline(schema) => *schema,
+            MetaSchemaRef::Reference(name) => {
+                T::register(self);
+                self.schemas
+                    .get(name)
+                    .cloned()
+                    .expect("You definitely encountered a bug!")
+            }
+        }
+    }
+
     pub fn create_tag(&mut self, tag: MetaTag) {
         self.tags.insert(tag);
     }
